# Automnated Annotation Tool

Single class image annotation tool using OpenCV.

## Example Use Cases
<img src="https://learnopencv.com/wp-content/uploads/2022/11/stags-and-boars-image-annotation-tool-opencv-contour-analysis.png" alt="Automated Annotation pyOpenAnnotate" width="900">

<img src="https://learnopencv.com/wp-content/uploads/2022/11/image-annotation-tool-coins-and-boxes-on-conveyor-opencv-contour-analysis.png" alt="Automated Annotation pyOpenAnnotate" width="900">

## Annotate Images

```
annotate --img <images_directory_path>
```

## Annotate Video
```
annotate --vid <path_to_video_file>
```
## Global Flags
```
-T : View mask window.
```
## Keyboard Navigation
```
N : Save and go to next image
B : Save and go back
C : Toggle clear screen 
T : Toggle mask window
Q : Quit
```
